package com.chelvc.framework.database.context;

import com.chelvc.framework.common.crypto.AESCipherFactory;
import com.chelvc.framework.common.util.ObjectUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.database.config.DatabaseProperties;
import lombok.NonNull;

/**
 * 数据库数据加解密上下文默认实现
 *
 * @author Woody
 * @date 2024/6/25
 */
public class DefaultDatabaseCryptoContext extends AESCipherFactory implements DatabaseCryptoContext {
    private final DatabaseProperties properties;

    public DefaultDatabaseCryptoContext(@NonNull DatabaseProperties properties) {
        super(ObjectUtils.ifNull(properties.getSensitive().getSecret(), StringUtils.EMPTY));
        this.properties = properties;
    }

    @Override
    public boolean isSensitiveMixed() {
        return this.properties.getSensitive().isMixed();
    }

    @Override
    public boolean isSensitiveWritable() {
        return this.properties.getSensitive().isWritable();
    }
}
